/*-
 * Copyright (c) 2010, Derek Konigsberg
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution. 
 * 3. Neither the name of the project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.logicprobe.recall;

import net.rim.device.api.system.ApplicationDescriptor;
import net.rim.device.api.system.Bitmap;
import net.rim.device.api.ui.Field;
import net.rim.device.api.ui.FieldChangeListener;
import net.rim.device.api.ui.Font;
import net.rim.device.api.ui.Screen;
import net.rim.device.api.ui.component.ButtonField;
import net.rim.device.api.ui.component.Dialog;
import net.rim.device.api.ui.component.LabelField;
import net.rim.device.api.ui.component.SeparatorField;

public class RecallScreen extends AbstractScreenProvider {
    private PlatformInfo platformInfo;
    private Field entryField;
    
    protected Object[] choices;
    
    public RecallScreen() {
        platformInfo = PlatformInfo.getInstance();
    }
    
    public void initFields(Screen screen) {
        super.initFields(screen);

        ApplicationDescriptor descriptor =
            ApplicationDescriptor.currentApplicationDescriptor();

        LabelField titleLabel = new LabelField(
                descriptor.getName(),
                Field.FIELD_HCENTER);
        titleLabel.setFont(Font.getDefault().derive(Font.BOLD));

        LabelField versionLabel = new LabelField(
                "Version: " + descriptor.getVersion(),
                Field.FIELD_HCENTER);
        
        LabelField platformLabel = new LabelField(
                "Platform: " + platformInfo.getPlatformVersion(),
                Field.FIELD_HCENTER);
        
        String text;
        if(platformInfo.hasTouchscreen()) {
            text = "Touchscreen";
        }
        else {
            text = "Keyboard";
        }
        LabelField touchscreenLabel = new LabelField(
                text, Field.FIELD_HCENTER);
        touchscreenLabel.setFont(Font.getDefault().derive(Font.ITALIC));
        
        LabelField crmLabel = new LabelField("CRM 114", Field.FIELD_HCENTER);
        crmLabel.setFont(Font.getDefault().derive(Font.BOLD, 30));
        
        entryField = UiFactory.getInstance().getCodeInputField();
        
        ButtonField transmitButton = new ButtonField("Transmit", ButtonField.CONSUME_CLICK | Field.FIELD_HCENTER);
        transmitButton.setChangeListener(new FieldChangeListener() {
            public void fieldChanged(Field field, int context) {
                transmitButtonChanged();
            }
        });
        
        screen.add(titleLabel);
        screen.add(versionLabel);
        screen.add(platformLabel);
        screen.add(touchscreenLabel);
        screen.add(new SeparatorField());
        screen.add(new LabelField());
        screen.add(crmLabel);
        screen.add(new LabelField());
        screen.add(entryField);
        screen.add(new LabelField());
        screen.add(transmitButton);
    }
    
    public boolean isDirty() {
        return false;
    }
    
    private void transmitButtonChanged() {
        String code = (String)entryField.getCookie();
        
        if(CodeValidator.validateCode(code)) {
            Dialog dialog = new Dialog(
                    Dialog.D_OK,
                    "Recall code transmitted",
                    Dialog.OK,
                    Bitmap.getPredefinedBitmap(Bitmap.INFORMATION), 0);
            dialog.doModal();
        }
        else {
            Dialog dialog = new Dialog(
                    Dialog.D_OK,
                    "Invalid code",
                    Dialog.OK,
                    Bitmap.getPredefinedBitmap(Bitmap.EXCLAMATION), 0);
            dialog.doModal();
        }
    }
}
