/*-
 * Copyright (c) 2010, Derek Konigsberg
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution. 
 * 3. Neither the name of the project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.logicprobe.recall;

import net.rim.device.api.ui.Color;
import net.rim.device.api.ui.Field;
import net.rim.device.api.ui.FieldChangeListener;
import net.rim.device.api.ui.component.SpinBoxField;
import net.rim.device.api.ui.component.TextSpinBoxField;
import net.rim.device.api.ui.container.SpinBoxFieldManager;
import net.rim.device.api.ui.decor.BackgroundFactory;

public class SpinBoxCodeField extends SpinBoxFieldManager {
    private Object[] choices;
    private SpinBoxField digit1Field;
    private SpinBoxField digit2Field;
    private SpinBoxField digit3Field;
    private StringBuffer codeBuffer;
    
    public SpinBoxCodeField() {
        super(Field.FIELD_HCENTER);
        
        setBackground(BackgroundFactory.createSolidBackground(Color.BLACK));
        setMargin(10, 10, 10, 10);
        
        choices = new Object[26];
        
        for(int i=0; i<26; i++) {
            choices[i] = new Character((char)('A' + i));
        }
        
        codeBuffer = new StringBuffer("   ");
        
        boolean isTouchscreen = PlatformInfo.getInstance().hasTouchscreen();
        
        digit1Field = new TextSpinBoxField(choices);
        digit1Field.setChangeListener(listener);
        digit2Field = new TextSpinBoxField(choices);
        digit2Field.setChangeListener(listener);
        digit3Field = new TextSpinBoxField(choices);
        digit3Field.setChangeListener(listener);
        
        setVisibleRows(3);
        setClickToLock(!isTouchscreen);
        
        add(digit1Field);
        add(digit2Field);
        add(digit3Field);
        
        updateCookie();
    }
    
    private FieldChangeListener listener = new FieldChangeListener() {
        public void fieldChanged(Field field, int context) {
            updateCookie();
        }
    };
    
    private void updateCookie() {
        int index1 = digit1Field.getSelectedIndex();
        int index2 = digit2Field.getSelectedIndex();
        int index3 = digit3Field.getSelectedIndex();
        
        codeBuffer.setCharAt(0, ((Character)choices[index1]).charValue());
        codeBuffer.setCharAt(1, ((Character)choices[index2]).charValue());
        codeBuffer.setCharAt(2, ((Character)choices[index3]).charValue());
        
        setCookie(codeBuffer.toString());
    }
}
